@@ -385,6 +385,11 @@ HandleEvent (const SDL_Event & event)
     }
     break;
 
+  case SDL_RENDER_DEVICE_RESET:
+  case SDL_RENDER_TARGETS_RESET:
+    g_pPixmap->ReloadTargetTextures ();
+    break;
+
   case SDL_USEREVENT:
   {
     switch (event.user.code)
@@ -723,7 +728,7 @@ DoInit (int argc, char * argv[], bool & exit)
 
   // Create a window.
   g_window = SDL_CreateWindow (
-    gettext ("Planet Blupi"), SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED,
+    gettext ("Planet Blupi"), SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED,
     LXIMAGE, LYIMAGE, 0);
 
   if (!g_window)
